pub fn run<F>(bundle: RunBundle, load_new: F)Expand description
Runs a RunBundle
Arguments
bundle- Optional bundle to run, if none is supplied the sdl window will open and wait for a game do be dropped onto it.load_new- Callback to get a new bundle from a file path, this will be called if a file is dragged onto the game window.